==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/alertsmanagement/kotlin/inputs/ConditionsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.alertsmanagement.kotlin.inputs

import com.pulumi.azurenative.alertsmanagement.inputs.ConditionsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Conditions in alert instance to be matched for a given action rule. Default value is all. Multiple values could be provided with comma separation.
 * @property alertContext filter alerts by alert context (payload)
 * @property alertRuleId filter alerts by alert rule id
 * @property alertRuleName filter alerts by alert rule name
 * @property description filter alerts by alert rule description
 * @property monitorCondition filter alerts by monitor condition
 * @property monitorService filter alerts by monitor service
 * @property severity filter alerts by severity
 * @property targetResourceType filter alerts by target resource type
 */
public data class ConditionsArgs(
    public val alertContext: Output<ConditionArgs>? = null,
    public val alertRuleId: Output<ConditionArgs>? = null,
    public val alertRuleName: Output<ConditionArgs>? = null,
    public val description: Output<ConditionArgs>? = null,
    public val monitorCondition: Output<ConditionArgs>? = null,
    public val monitorService: Output<ConditionArgs>? = null,
    public val severity: Output<ConditionArgs>? = null,
    public val targetResourceType: Output<ConditionArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.alertsmanagement.inputs.ConditionsArgs> {
    override fun toJava(): com.pulumi.azurenative.alertsmanagement.inputs.ConditionsArgs =
        com.pulumi.azurenative.alertsmanagement.inputs.ConditionsArgs.builder()
            .alertContext(alertContext?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .alertRuleId(alertRuleId?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .alertRuleName(alertRuleName?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .description(description?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .monitorCondition(monitorCondition?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .monitorService(monitorService?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .severity(severity?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .targetResourceType(
                targetResourceType?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [ConditionsArgs].
 */
@PulumiTagMarker
public class ConditionsArgsBuilder internal constructor() {
    private var alertContext: Output<ConditionArgs>? = null

    private var alertRuleId: Output<ConditionArgs>? = null

    private var alertRuleName: Output<ConditionArgs>? = null

    private var description: Output<ConditionArgs>? = null

    private var monitorCondition: Output<ConditionArgs>? = null

    private var monitorService: Output<ConditionArgs>? = null

    private var severity: Output<ConditionArgs>? = null

    private var targetResourceType: Output<ConditionArgs>? = null

    /**
     * @param value filter alerts by alert context (payload)
     */
    @JvmName("obvoyyslhslkunby")
    public suspend fun alertContext(`value`: Output<ConditionArgs>) {
        this.alertContext = value
    }

    /**
     * @param value filter alerts by alert rule id
     */
    @JvmName("hpyksmunalokcujm")
    public suspend fun alertRuleId(`value`: Output<ConditionArgs>) {
        this.alertRuleId = value
    }

    /**
     * @param value filter alerts by alert rule name
     */
    @JvmName("fqbmrifwjtsfipag")
    public suspend fun alertRuleName(`value`: Output<ConditionArgs>) {
        this.alertRuleName = value
    }

    /**
     * @param value filter alerts by alert rule description
     */
    @JvmName("pbimnidwjepohenb")
    public suspend fun description(`value`: Output<ConditionArgs>) {
        this.description = value
    }

    /**
     * @param value filter alerts by monitor condition
     */
    @JvmName("xxlrdkgscmqqdsxb")
    public suspend fun monitorCondition(`value`: Output<ConditionArgs>) {
        this.monitorCondition = value
    }

    /**
     * @param value filter alerts by monitor service
     */
    @JvmName("fsostgjomeqfeywq")
    public suspend fun monitorService(`value`: Output<ConditionArgs>) {
        this.monitorService = value
    }

    /**
     * @param value filter alerts by severity
     */
    @JvmName("fulirhhecwetkmmt")
    public suspend fun severity(`value`: Output<ConditionArgs>) {
        this.severity = value
    }

    /**
     * @param value filter alerts by target resource type
     */
    @JvmName("sbjmupoyjtpyvmwa")
    public suspend fun targetResourceType(`value`: Output<ConditionArgs>) {
        this.targetResourceType = value
    }

    /**
     * @param value filter alerts by alert context (payload)
     */
    @JvmName("qucsfeqiigorligx")
    public suspend fun alertContext(`value`: ConditionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.alertContext = mapped
    }

    /**
     * @param argument filter alerts by alert context (payload)
     */
    @JvmName("dhifsfndxpengilw")
    public suspend fun alertContext(argument: suspend ConditionArgsBuilder.() -> Unit) {
        val toBeMapped = ConditionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.alertContext = mapped
    }

    /**
     * @param value filter alerts by alert rule id
     */
    @JvmName("ajmqckuelayarxku")
    public suspend fun alertRuleId(`value`: ConditionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.alertRuleId = mapped
    }

    /**
     * @param argument filter alerts by alert rule id
     */
    @JvmName("hyqflvkvoplxxcrs")
    public suspend fun alertRuleId(argument: suspend ConditionArgsBuilder.() -> Unit) {
        val toBeMapped = ConditionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.alertRuleId = mapped
    }

    /**
     * @param value filter alerts by alert rule name
     */
    @JvmName("jxtupqjfqyibrbiu")
    public suspend fun alertRuleName(`value`: ConditionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.alertRuleName = mapped
    }

    /**
     * @param argument filter alerts by alert rule name
     */
    @JvmName("klxuqkjbaendesaj")
    public suspend fun alertRuleName(argument: suspend ConditionArgsBuilder.() -> Unit) {
        val toBeMapped = ConditionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.alertRuleName = mapped
    }

    /**
     * @param value filter alerts by alert rule description
     */
    @JvmName("ycveguogmltvatrx")
    public suspend fun description(`value`: ConditionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param argument filter alerts by alert rule description
     */
    @JvmName("kduawbchtsjdehir")
    public suspend fun description(argument: suspend ConditionArgsBuilder.() -> Unit) {
        val toBeMapped = ConditionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.description = mapped
    }

    /**
     * @param value filter alerts by monitor condition
     */
    @JvmName("nhtqkjhvrjodblww")
    public suspend fun monitorCondition(`value`: ConditionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.monitorCondition = mapped
    }

    /**
     * @param argument filter alerts by monitor condition
     */
    @JvmName("aajrphhjsjmvfcmq")
    public suspend fun monitorCondition(argument: suspend ConditionArgsBuilder.() -> Unit) {
        val toBeMapped = ConditionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.monitorCondition = mapped
    }

    /**
     * @param value filter alerts by monitor service
     */
    @JvmName("cbwvtcufuhkxtbch")
    public suspend fun monitorService(`value`: ConditionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.monitorService = mapped
    }

    /**
     * @param argument filter alerts by monitor service
     */
    @JvmName("klprbfqdjreqipiu")
    public suspend fun monitorService(argument: suspend ConditionArgsBuilder.() -> Unit) {
        val toBeMapped = ConditionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.monitorService = mapped
    }

    /**
     * @param value filter alerts by severity
     */
    @JvmName("xnavidyefvubssxq")
    public suspend fun severity(`value`: ConditionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.severity = mapped
    }

    /**
     * @param argument filter alerts by severity
     */
    @JvmName("jbxpfmtweubuxaao")
    public suspend fun severity(argument: suspend ConditionArgsBuilder.() -> Unit) {
        val toBeMapped = ConditionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.severity = mapped
    }

    /**
     * @param value filter alerts by target resource type
     */
    @JvmName("blvbalymqftrufbu")
    public suspend fun targetResourceType(`value`: ConditionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.targetResourceType = mapped
    }

    /**
     * @param argument filter alerts by target resource type
     */
    @JvmName("kixebidlqfvuyjun")
    public suspend fun targetResourceType(argument: suspend ConditionArgsBuilder.() -> Unit) {
        val toBeMapped = ConditionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.targetResourceType = mapped
    }

    internal fun build(): ConditionsArgs = ConditionsArgs(
        alertContext = alertContext,
        alertRuleId = alertRuleId,
        alertRuleName = alertRuleName,
        description = description,
        monitorCondition = monitorCondition,
        monitorService = monitorService,
        severity = severity,
        targetResourceType = targetResourceType,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/alertsmanagement/kotlin/inputs/ConditionsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.alertsmanagement.kotlin.inputs

import com.pulumi.azurenative.alertsmanagement.inputs.ConditionsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Conditions in alert instance to be matched for a given action rule. Default value is all. Multiple values could be provided with comma separation.
 * @property alertContext filter alerts by alert context (payload)
 * @property alertRuleId filter alerts by alert rule id
 * @property alertRuleName filter alerts by alert rule name
 * @property description filter alerts by alert rule description
 * @property monitorCondition filter alerts by monitor condition
 * @property monitorService filter alerts by monitor service
 * @property severity filter alerts by severity
 * @property targetResourceType filter alerts by target resource type
 */
public data class ConditionsArgs(
    public val alertContext: Output<ConditionArgs>? = null,
    public val alertRuleId: Output<ConditionArgs>? = null,
    public val alertRuleName: Output<ConditionArgs>? = null,
    public val description: Output<ConditionArgs>? = null,
    public val monitorCondition: Output<ConditionArgs>? = null,
    public val monitorService: Output<ConditionArgs>? = null,
    public val severity: Output<ConditionArgs>? = null,
    public val targetResourceType: Output<ConditionArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.alertsmanagement.inputs.ConditionsArgs> {
    override fun toJava(): com.pulumi.azurenative.alertsmanagement.inputs.ConditionsArgs =
        com.pulumi.azurenative.alertsmanagement.inputs.ConditionsArgs.builder()
            .alertContext(alertContext?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .alertRuleId(alertRuleId?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .alertRuleName(alertRuleName?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .description(description?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .monitorCondition(monitorCondition?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .monitorService(monitorService?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .severity(severity?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .targetResourceType(
                targetResourceType?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [ConditionsArgs].
 */
@PulumiTagMarker
public class ConditionsArgsBuilder internal constructor() {
    private var alertContext: Output<ConditionArgs>? = null

    private var alertRuleId: Output<ConditionArgs>? = null

    private var alertRuleName: Output<ConditionArgs>? = null

    private var description: Output<ConditionArgs>? = null

    private var monitorCondition: Output<ConditionArgs>? = null

    private var monitorService: Output<ConditionArgs>? = null

    private var severity: Output<ConditionArgs>? = null

    private var targetResourceType: Output<ConditionArgs>? = null

    /**
     * @param value filter alerts by alert context (payload)
     */
    @JvmName("bjyoruwndquqmwie")
    public suspend fun alertContext(`value`: Output<ConditionArgs>) {
        this.alertContext = value
    }

    /**
     * @param value filter alerts by alert rule id
     */
    @JvmName("lcbxuxadquuutrdq")
    public suspend fun alertRuleId(`value`: Output<ConditionArgs>) {
        this.alertRuleId = value
    }

    /**
     * @param value filter alerts by alert rule name
     */
    @JvmName("rbmuioklxibopxkb")
    public suspend fun alertRuleName(`value`: Output<ConditionArgs>) {
        this.alertRuleName = value
    }

    /**
     * @param value filter alerts by alert rule description
     */
    @JvmName("frfiegcejsogjkqh")
    public suspend fun description(`value`: Output<ConditionArgs>) {
        this.description = value
    }

    /**
     * @param value filter alerts by monitor condition
     */
    @JvmName("ofdfyvybkpkeloci")
    public suspend fun monitorCondition(`value`: Output<ConditionArgs>) {
        this.monitorCondition = value
    }

    /**
     * @param value filter alerts by monitor service
     */
    @JvmName("jrmvggneaqhcxnht")
    public suspend fun monitorService(`value`: Output<ConditionArgs>) {
        this.monitorService = value
    }

    /**
     * @param value filter alerts by severity
     */
    @JvmName("ogethflucurxmypt")
    public suspend fun severity(`value`: Output<ConditionArgs>) {
        this.severity = value
    }

    /**
     * @param value filter alerts by target resource type
     */
    @JvmName("khyeovuovxqhimwy")
    public suspend fun targetResourceType(`value`: Output<ConditionArgs>) {
        this.targetResourceType = value
    }

    /**
     * @param value filter alerts by alert context (payload)
     */
    @JvmName("rdgxvfiaarmvfvwf")
    public suspend fun alertContext(`value`: ConditionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.alertContext = mapped
    }

    /**
     * @param argument filter alerts by alert context (payload)
     */
    @JvmName("ictvulwlcwqpmolw")
    public suspend fun alertContext(argument: suspend ConditionArgsBuilder.() -> Unit) {
        val toBeMapped = ConditionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.alertContext = mapped
    }

    /**
     * @param value filter alerts by alert rule id
     */
    @JvmName("acssryraylhvdfvn")
    public suspend fun alertRuleId(`value`: ConditionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.alertRuleId = mapped
    }

    /**
     * @param argument filter alerts by alert rule id
     */
    @JvmName("nbomawfqcjpyeqgs")
    public suspend fun alertRuleId(argument: suspend ConditionArgsBuilder.() -> Unit) {
        val toBeMapped = ConditionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.alertRuleId = mapped
    }

    /**
     * @param value filter alerts by alert rule name
     */
    @JvmName("upeqwvviubtntlef")
    public suspend fun alertRuleName(`value`: ConditionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.alertRuleName = mapped
    }

    /**
     * @param argument filter alerts by alert rule name
     */
    @JvmName("yhipduqeeikatdch")
    public suspend fun alertRuleName(argument: suspend ConditionArgsBuilder.() -> Unit) {
        val toBeMapped = ConditionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.alertRuleName = mapped
    }

    /**
     * @param value filter alerts by alert rule description
     */
    @JvmName("lmohqkrlrwenpwlt")
    public suspend fun description(`value`: ConditionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param argument filter alerts by alert rule description
     */
    @JvmName("pnmooolhusikoilr")
    public suspend fun description(argument: suspend ConditionArgsBuilder.() -> Unit) {
        val toBeMapped = ConditionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.description = mapped
    }

    /**
     * @param value filter alerts by monitor condition
     */
    @JvmName("lowrootfvgqvjuwf")
    public suspend fun monitorCondition(`value`: ConditionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.monitorCondition = mapped
    }

    /**
     * @param argument filter alerts by monitor condition
     */
    @JvmName("eysakptaymyfxfqu")
    public suspend fun monitorCondition(argument: suspend ConditionArgsBuilder.() -> Unit) {
        val toBeMapped = ConditionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.monitorCondition = mapped
    }

    /**
     * @param value filter alerts by monitor service
     */
    @JvmName("yffmwybbcypcldgu")
    public suspend fun monitorService(`value`: ConditionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.monitorService = mapped
    }

    /**
     * @param argument filter alerts by monitor service
     */
    @JvmName("cvtyfftkbgsoukcb")
    public suspend fun monitorService(argument: suspend ConditionArgsBuilder.() -> Unit) {
        val toBeMapped = ConditionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.monitorService = mapped
    }

    /**
     * @param value filter alerts by severity
     */
    @JvmName("vhhmpgehfjyppglk")
    public suspend fun severity(`value`: ConditionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.severity = mapped
    }

    /**
     * @param argument filter alerts by severity
     */
    @JvmName("xiqbxvqbmuodnwks")
    public suspend fun severity(argument: suspend ConditionArgsBuilder.() -> Unit) {
        val toBeMapped = ConditionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.severity = mapped
    }

    /**
     * @param value filter alerts by target resource type
     */
    @JvmName("iaaquhdpwxdiexvf")
    public suspend fun targetResourceType(`value`: ConditionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.targetResourceType = mapped
    }

    /**
     * @param argument filter alerts by target resource type
     */
    @JvmName("qycdhjwedhopwjuo")
    public suspend fun targetResourceType(argument: suspend ConditionArgsBuilder.() -> Unit) {
        val toBeMapped = ConditionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.targetResourceType = mapped
    }

    internal fun build(): ConditionsArgs = ConditionsArgs(
        alertContext = alertContext,
        alertRuleId = alertRuleId,
        alertRuleName = alertRuleName,
        description = description,
        monitorCondition = monitorCondition,
        monitorService = monitorService,
        severity = severity,
        targetResourceType = targetResourceType,
    )
}
